@@ -58,7 +58,7 @@ struct LoadGraph {
     double graph_delx;
     guint graph_buffer_offset;
 
-    std::vector<GdkColor> colors;
+    std::vector<GdkRGBA> colors;
 
     std::vector<float> data_block;
     gfloat* data[NUM_POINTS];
@@ -66,11 +66,7 @@ struct LoadGraph {
     GtkWidget *main_widget;
     GtkWidget *disp;
 
-#if GTK_CHECK_VERSION(3,0,0)
-    cairo_surface_t *background;
-#else
-    GdkDrawable *background;
-#endif
+    cairo_pattern_t *background;
 
     guint timer_index;
 
