@@ -57,7 +57,7 @@ PrettyTable::on_application_opened(WnckScreen* screen, WnckApplication* app, gpo
     f = fopen (icon_name, "r");
     if (f != NULL) {
         fclose (f);
-        icon = that->theme->load_icon(icon_name, APP_ICON_SIZE, Gtk::ICON_LOOKUP_USE_BUILTIN);
+        icon = that->theme->load_icon(icon_name, APP_ICON_SIZE);
     }
 
     if (not icon) {
@@ -116,7 +116,7 @@ PrettyTable::unregister_application(pid_t pid)
 Glib::RefPtr<Gdk::Pixbuf>
 PrettyTable::get_icon_from_theme(const ProcInfo &info)
 {
-    return this->theme->load_icon(info.name, APP_ICON_SIZE, Gtk::ICON_LOOKUP_USE_BUILTIN | Gtk::ICON_LOOKUP_FORCE_SIZE);
+    return this->theme->load_icon(info.name, APP_ICON_SIZE);
 }
 
 
@@ -149,7 +149,7 @@ PrettyTable::get_icon_from_default(const ProcInfo &info)
         IconCache::iterator it(this->defaults.find(name));
 
         if (it == this->defaults.end()) {
-            pix = this->theme->load_icon(name, APP_ICON_SIZE, Gtk::ICON_LOOKUP_USE_BUILTIN | Gtk::ICON_LOOKUP_FORCE_SIZE);
+            pix = this->theme->load_icon(name, APP_ICON_SIZE);
             if (pix)
                 this->defaults[name] = pix;
             } else
@@ -179,14 +179,14 @@ PrettyTable::get_icon_from_wnck(const ProcInfo &info)
 Glib::RefPtr<Gdk::Pixbuf>
 PrettyTable::get_icon_from_name(const ProcInfo &info)
 {
-    return this->theme->load_icon(info.name, APP_ICON_SIZE, Gtk::ICON_LOOKUP_USE_BUILTIN | Gtk::ICON_LOOKUP_FORCE_SIZE);
+    return this->theme->load_icon(info.name, APP_ICON_SIZE);
 }
 
 
 Glib::RefPtr<Gdk::Pixbuf>
 PrettyTable::get_icon_dummy(const ProcInfo &)
 {
-    return this->theme->load_icon("application-x-executable", APP_ICON_SIZE, Gtk::ICON_LOOKUP_USE_BUILTIN);
+    return this->theme->load_icon("application-x-executable", APP_ICON_SIZE);
 }
 
 
@@ -212,7 +212,7 @@ Glib::RefPtr<Gdk::Pixbuf>
 PrettyTable::get_icon_for_kernel(const ProcInfo &info)
 {
     if (is_kthread(info))
-        return this->theme->load_icon("applications-system", APP_ICON_SIZE, Gtk::ICON_LOOKUP_USE_BUILTIN);
+        return this->theme->load_icon("applications-system", APP_ICON_SIZE);
 
     return Glib::RefPtr<Gdk::Pixbuf>();
 }
