@@ -49,7 +49,7 @@ enum
     COL_SEAT,
     COL_OWNER,
     COL_PRIORITY,
-    COL_PIXBUF,
+    COL_SURFACE,
     COL_POINTER,
     COL_TOOLTIP,
     NUM_COLUMNS
