@@ -72,12 +72,28 @@ namespace {
                         ("<big><big><b>" + this->distro_name + "</b></big></big>").c_str(),
                         NULL);
 
+            char* markup;
+#ifdef __linux__
+            if (this->distro_release != "")
+            {
+                /* Translators: The first string parameter is release version (codename),
+                 * the second one is the architecture, 32 or 64-bit */
+                markup = g_strdup_printf(_("Release %s %s"),
+                                         this->distro_release.c_str(),
+                                         this->get_os_type().c_str());
+            }
+            else
+            {
+                /* Translators: The string parameter is the architecture, 32 or 64-bit */
+                markup = g_strdup_printf(_("%s Version"),
+                                         this->get_os_type().c_str());
+            }
+#else
+            /* Translators: The string parameter is release version (codename) */
+            markup = g_strdup_printf(_("Release %s"),
+                                     this->distro_release.c_str());
+#endif
 
-            /* Translators: The first string parameter is release version (codename),
-             * the second one is the architecture, 32 or 64-bit */
-            char* markup = g_strdup_printf(_("Release %s %s"),
-                                           this->distro_release.c_str(),
-                                           this->get_os_type().c_str());
             g_object_set(G_OBJECT(release),
                          "label",
                          markup,
@@ -86,6 +102,11 @@ namespace {
             g_free(markup);
         }
 
+        static string release()
+        {
+            return uname().release;
+        }
+
         static string system()
         {
             return uname().sysname;
@@ -258,6 +279,14 @@ namespace {
             this->free_space_bytes = 0;
 
             for (guint i = 0; i != mountlist.number; ++i) {
+                if ((string(entries[i].mountdir).compare("/") == 0) && \
+                    (string(entries[i].type).compare("zfs") == 0)) {
+                    // Root filesystem is ZFS based: Calculate usage based on "/".
+                    glibtop_fsusage usage;
+                    glibtop_get_fsusage(&usage, "/");
+                    this->free_space_bytes = usage.bavail * usage.block_size;
+                    break;
+                }
 
                 if (string(entries[i].devname).find("/dev/") != 0)
                     continue;
@@ -287,7 +316,13 @@ namespace {
         void load_uname_info()
         {
             this->hostname = uname().nodename;
+#if defined(__linux__)
             this->kernel = string(uname().sysname) + ' ' + uname().release + ' ' + uname().machine;
+#elif defined(__sun) && defined(__SVR4)
+            this->kernel = string(uname().sysname) + ' ' + uname().release + ' ' + uname().version + ' ' + uname().machine;
+#else
+            this->kernel = string(uname().version) + ' ' + uname().machine;
+#endif
         }
 
 
@@ -325,7 +360,22 @@ namespace {
         }
     };
 
+    class FreeBSDSysInfo
+        : public SysInfo
+    {
+    public:
+	FreeBSDSysInfo()
+        {
+            this->load_freebsd_info();
+        }
 
+    private:
+        void load_freebsd_info()
+        {
+            this->distro_name = "FreeBSD";
+            this->distro_release = release();
+        }
+    };
 
     class SolarisSysInfo
         : public SysInfo
@@ -339,12 +389,23 @@ namespace {
     private:
         void load_solaris_info()
         {
-            this->distro_name = "Solaris";
-
             std::ifstream input("/etc/release");
 
-            if (input)
-                std::getline(input, this->distro_release);
+            if (input) {
+                std::string s;
+                std::getline(input, s);
+                std::size_t found = s.find("OpenIndiana ");
+                if (found!=std::string::npos) {
+                    this->distro_name = "OpenIndiana";
+                    this->distro_release = s.substr(found + strlen("OpenIndiana "));
+                } else if (!s.empty()) {
+                    this->distro_release = s;
+                }
+            }
+
+            if (this->distro_release.empty()) {
+                this->distro_name = "Solaris";
+            }
         }
     };
 
@@ -532,16 +593,32 @@ namespace {
             if (input) {
                 while (!input.eof()) {
                     string s;
-                    int len;
+                    int start;
                     std::getline(input, s);
                     if (s.find("NAME=") == 0) {
-                        len = strlen("NAME=");
-                        this->distro_name = s.substr(len);
+                        start = strlen("NAME=");
+                        if ((s.at(start) == '\"') && (s.at(s.size() - 1) == '\"')) {
+                            this->distro_name = s.substr(start + 1, s.size() - start - 2);
+                        } else {
+                            this->distro_name = s.substr(start);
+                        }
                     } else if (s.find("VERSION=") == 0) {
-                        len = strlen("VERSION=");
+                        start = strlen("VERSION=");
                         // also strip the surrounding quotes
-                       this->distro_release = s.substr(len + 1, s.size() - len - 2);
-                   }
+                        this->distro_release = s.substr(start + 1, s.size() - start - 2);
+                    } else if (s.find("# VERSION=") == 0) {
+                        start = strlen("# VERSION=");
+                        // also strip the surrounding quotes
+                        this->distro_release = s.substr(start + 1, s.size() - start - 2);
+                    }
+                }
+                input.close();
+                input.clear();
+            }
+            if (this->distro_release.empty()) {
+                input.open("/etc/debian_version");
+                if (input) {
+                    getline(input, this->distro_release);
                 }
             }
         }
@@ -610,6 +687,9 @@ namespace {
             g_free(p);
             return new LSBSysInfo;
         }
+        else if (SysInfo::system() == "FreeBSD") {
+            return new FreeBSDSysInfo;
+        }
         else if (SysInfo::system() == "SunOS") {
             return new SolarisSysInfo;
         }
